uma-ase WebApp

## Input Details

Input file
Charge
Spin Multiplicity

### Summary

    No structure loaded.

Viewer loading...

Viewer file: No file selected
Loaded structure: None

## Input Details

Selected Input file No file selected
Charge
Spin Multiplicity
MLFF Checkpoint
MLFF Task
Run Type
Single Point GeoOpt Frequencies
Optimizer
Force (eV/Å)
Max GeoOpt Iter

Vib Analysis Settings

Temperature (K)
Pressure (Pa)

### Summary

    No structure loaded.

## Results

Select an input file and run a job to see results here.

## Input Details

Select a Folder
No folder selected
MLFF Checkpoint
MLFF Task
Run Type
Single Point GeoOpt Frequencies
Optimizer
Force (eV/Å)
Max Iter

Vib Analysis Settings

Temperature (K)
Pressure (Pa)

### Summary

    No folder selected.

## Results

## Analyze

Select a folder

#### RMSD Report

Reads uma-ase .log files (Formula, RMSD, uma model, optimizer) and generates a bar plot and a table of RMSDs by formula.

#### XYZ Pair Analysis

Matches *.xyz files with their *geoopt-OPT* counterparts and detailed geometry analysis. Python script provided by A. Solé-Daura.

## Input Details

Selected Input file No file selected
Charge
Spin Multiplicity
MLFF Checkpoint
MLFF Task
Dynamics Engine
Steps
Timestep (fs)
Target Temperature (K)
Friction (1/fs)
Thermostat Relaxation (fs)
Target Pressure (bar)
Compressibility (1/bar)
Barostat Relaxation (fs)

Nosé-Hoover Parameters

Thermostat Damping (fs)
Chain Length
Thermostat Sub-steps
Bussi Time Constant (fs)
Andersen Collision Probability

MTK Parameters

Thermostat Damping (fs)
Barostat Damping (fs)
Thermostat Chain Length
Barostat Chain Length
Thermostat Sub-steps
Barostat Sub-steps
BAOAB Thermostat Tau (fs)

BAOAB Barostat Options

Barostat Tau (fs)
Cell Mass (ASE units)
Mass Factor
Hydrostatic cell (preserve shape)

Melchionna Controls

Thermostat Time (fs)
Barostat Time (fs)
Bulk Modulus (GPa)
Mask (comma separated, e.g. 1,1,1)

Periodic Boundary Conditions

Apply periodic boundary conditions
Cell a (Å)
Cell b (Å)
Cell c (Å)
Alpha (°)
Beta (°)
Gamma (°)
Trajectory Interval (steps)
Log Interval (steps)

### Summary

    No structure loaded.

## MD Output

Upload a structure and configure molecular dynamics options to begin.